==> mysql-8.0_8.0.28.orig.tar.gz: mysql-8.0.28/sql/dd/impl/system_views/system_view_impl.h <==
/* Copyright (c) 2017, 2021, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is also distributed with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have included with MySQL.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA */

#ifndef DD_SYSTEM_VIEWS__SYSTEM_VIEW_IMPL_INCLUDED
#define DD_SYSTEM_VIEWS__SYSTEM_VIEW_IMPL_INCLUDED

#include "sql/dd/types/system_view.h"  // System_view

namespace dd {
namespace system_views {

template <typename T>
class System_view_impl : virtual public System_view {
 public:
  const System_view_definition *view_definition() const override {
    return &m_target_def;
  }

  bool hidden() const override { return false; }

 protected:
  T m_target_def;
};

}  // namespace system_views
}  // namespace dd

#endif  // DD_SYSTEM_VIEWS__SYSTEM_VIEW_IMPL_INCLUDED

==> mysql-8.4.8.tar.gz: mysql-8.4.8/sql/dd/impl/system_views/system_view_impl.h <==
/* Copyright (c) 2017, 2025, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is designed to work with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have either included with
   the program or referenced in the documentation.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA */

#ifndef DD_SYSTEM_VIEWS__SYSTEM_VIEW_IMPL_INCLUDED
#define DD_SYSTEM_VIEWS__SYSTEM_VIEW_IMPL_INCLUDED

#include "sql/dd/types/system_view.h"  // System_view

namespace dd {
namespace system_views {

template <typename T>
class System_view_impl : virtual public System_view {
 public:
  const System_view_definition *view_definition() const override {
    return &m_target_def;
  }

  bool hidden() const override { return false; }

 protected:
  T m_target_def;
};

}  // namespace system_views
}  // namespace dd

#endif  // DD_SYSTEM_VIEWS__SYSTEM_VIEW_IMPL_INCLUDED
